@@ -36,3 +36,11 @@ class DeprecationError(RuntimeError):
     def __init__(self, message='This feature has been depreciated'):
         """Empty init."""
         RuntimeError.__init__(self, message)
+
+
+class VTKVersionError(RuntimeError):
+    """Requested feature is not supported by the installed VTK version."""
+
+    def __init__(self, message='The requested feature is not supported by the installed VTK version.'):
+        """Empty init."""
+        RuntimeError.__init__(self, message)
