@@ -3,18 +3,17 @@
 The data objects does not have any sort of spatial reference.
 
 """
-import imageio
 import numpy as np
-import vtk
 
+from pyvista import _vtk
 import pyvista
 from pyvista.utilities import (FieldAssociation, assert_empty_kwargs, get_array,
                                row_array)
-from .common import DataObject
+from .dataset import DataObject
 from .datasetattributes import DataSetAttributes
 
 
-class Table(vtk.vtkTable, DataObject):
+class Table(_vtk.vtkTable, DataObject):
     """Wrapper for the ``vtkTable`` class.
 
     Create by passing a 2D NumPy array of shape (``n_rows`` by ``n_columns``)
@@ -33,7 +32,7 @@ class Table(vtk.vtkTable, DataObject):
         """Initialize the table."""
         super().__init__(*args, **kwargs)
         if len(args) == 1:
-            if isinstance(args[0], vtk.vtkTable):
+            if isinstance(args[0], _vtk.vtkTable):
                 deep = kwargs.get('deep', True)
                 if deep:
                     self.deep_copy(args[0])
@@ -241,14 +240,14 @@ class Table(vtk.vtkTable, DataObject):
         """Create a Pandas DataFrame from this Table."""
         try:
             import pandas as pd
-        except ImportError:
+        except ImportError:  # pragma: no cover
             raise ImportError('Install ``pandas`` to use this feature.')
         data_frame = pd.DataFrame()
         for name, array in self.items():
             data_frame[name] = array
         return data_frame
 
-    def save(self, *args, **kwargs):
+    def save(self, *args, **kwargs):  # pragma: no cover
         """Save the table."""
         raise NotImplementedError("Please use the `to_pandas` method and "
                                   "harness Pandas' wonderful file IO methods.")
@@ -280,40 +279,34 @@ class Table(vtk.vtkTable, DataObject):
         return np.nanmin(arr), np.nanmax(arr)
 
 
-class Texture(vtk.vtkTexture, DataObject):
+class Texture(_vtk.vtkTexture, DataObject):
     """A helper class for vtkTextures."""
 
-    _READERS = {'.bmp': vtk.vtkBMPReader, '.dem': vtk.vtkDEMReader, '.dcm': vtk.vtkDICOMImageReader,
-                '.img': vtk.vtkDICOMImageReader, '.jpeg': vtk.vtkJPEGReader, '.jpg': vtk.vtkJPEGReader,
-                '.mhd': vtk.vtkMetaImageReader, '.nrrd': vtk.vtkNrrdReader, '.nhdr': vtk.vtkNrrdReader,
-                '.png': vtk.vtkPNGReader, '.pnm': vtk.vtkPNMReader, '.slc': vtk.vtkSLCReader,
-                '.tiff': vtk.vtkTIFFReader, '.tif': vtk.vtkTIFFReader}
-
     def __init__(self, *args, **kwargs):
         """Initialize the texture."""
         super().__init__(*args, **kwargs)
-        assert_empty_kwargs(**kwargs)
 
         if len(args) == 1:
-            if isinstance(args[0], vtk.vtkTexture):
+            if isinstance(args[0], _vtk.vtkTexture):
                 self._from_texture(args[0])
             elif isinstance(args[0], np.ndarray):
                 self._from_array(args[0])
-            elif isinstance(args[0], vtk.vtkImageData):
+            elif isinstance(args[0], _vtk.vtkImageData):
                 self._from_image_data(args[0])
             elif isinstance(args[0], str):
-                self._from_file(filename=args[0])
+                self._from_file(filename=args[0], **kwargs)
             else:
-                raise TypeError(f'Table unable to be made from ({type(args[0])})')
+                raise TypeError(f'Texture unable to be made from ({type(args[0])})')
 
-    def _from_file(self, filename):
+    def _from_file(self, filename, **kwargs):
         try:
-            image = self._load_file(filename)
+            image = pyvista.read(filename, **kwargs)
             if image.GetNumberOfPoints() < 2:
                 raise ValueError("Problem reading the image with VTK.")
             self._from_image_data(image)
         except (KeyError, ValueError):
-            self._from_array(imageio.imread(filename))
+            from imageio import imread
+            self._from_array(imread(filename))
 
     def _from_texture(self, texture):
         image = texture.GetInput()
@@ -385,6 +378,29 @@ class Texture(vtk.vtkTexture, DataObject):
         """Plot the texture as image data by itself."""
         return self.to_image().plot(*args, **kwargs)
 
+    @property
+    def cube_map(self):
+        """Return ``True`` if cube mapping is enabled and ``False`` otherwise.
+
+        Is this texture a cube map, if so it needs 6 inputs, one for
+        each side of the cube. You must set this before connecting the
+        inputs.  The inputs must all have the same size, data type,
+        and depth.
+        """
+        return self.GetCubeMap()
+
+    @cube_map.setter
+    def cube_map(self, flag):
+        """Enable cube mapping if ``flag`` is True, disable it otherwise."""
+        self.SetCubeMap(flag)
+
     def copy(self):
         """Make a copy of this texture."""
         return Texture(self.to_image().copy())
+
+    def to_skybox(self):
+        """Return the texture as a ``vtkSkybox`` if cube mapping is enabled."""
+        if self.cube_map:
+            skybox = _vtk.vtkSkybox()
+            skybox.SetTexture(self)
+            return skybox
