@@ -342,7 +342,10 @@ class RenderWindowInteractor():
     def create_repeating_timer(self, stime):
         """Create a repeating timer."""
         timer_id = self.interactor.CreateRepeatingTimer(stime)
-        self.interactor.Start()
+        if hasattr(self.interactor, 'ProcessEvents'):
+            self.process_events()
+        else:
+            self.interactor.Start()
         self.interactor.DestroyTimer(timer_id)
         return timer_id
 
@@ -385,7 +388,8 @@ class RenderWindowInteractor():
 
     def terminate_app(self):
         """Terminate the app."""
-        self.interactor.TerminateApp()
+        if self.initialized:
+            self.interactor.TerminateApp()
 
 
 def _style_factory(klass):
